@@ -120,7 +120,6 @@ urlpatterns = [
     url(r'^$', index, name='lava_dashboard'),
     url(r'^filters/$', filters_list, name='lava_dashboard_filters_list'),
     url(r'^filters/filters_names_json$', filter_name_list_json, name='filter_name_list_json'),
-    url(r'^filters/\+add$', filter_add, name='dashboard_app.views.filters.views.filter_add'),
     url(r'^filters/\+add-cases-for-test-json$', filter_add_cases_for_test_json,
         name='dashboard_app.views.filters.views.filter_add_cases_for_test_json'),
     url(r'^filters/\+get-tests-json$', get_tests_json),
@@ -131,10 +130,6 @@ urlpatterns = [
         name='dashboard_app.views.filters.views.filter_attr_value_completion_json'),
     url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)$', filter_detail,
         name='dashboard_app.views.filters.views.filter_detail'),
-    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+edit$', filter_edit,
-        name='dashboard_app.views.filters.views.filter_edit'),
-    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+copy$', filter_copy,
-        name='dashboard_app.views.filters.views.filter_copy'),
     url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+subscribe$', filter_subscribe,
         name='dashboard_app.views.filters.views.filter_subscribe'),
     url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+delete$', filter_delete,
@@ -209,17 +204,9 @@ urlpatterns = [
         name='image_report_select_group'),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+order-update$', image_report_order_update,
         name='image_report_order_update'),
-    url(r'^image-charts/\+add$', image_report_add,
-        name='dashboard_app.views.image_reports.views.image_report_add'),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+edit$', image_report_edit),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+delete$', image_report_delete),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+publish$', image_report_publish),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+unpublish$', image_report_unpublish),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)$', image_chart_detail,
         name='dashboard_app.views.image_reports.views.image_chart_detail'),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+add$', image_chart_add,
-        name='dashboard_app.views.image_reports.views.image_chart_add'),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+edit$', image_chart_edit),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+delete$', image_chart_delete),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+settings-update$', image_chart_settings_update),
     url(r'^image-charts/\+filter-type-check$', image_chart_filter_type_check),
@@ -227,10 +214,8 @@ urlpatterns = [
     url(r'^image-charts/\+get-group-names$', get_group_names,
         name='dashboard_app.views.image_reports.views.get_group_names'),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+export$', image_chart_export),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+add-filter$', image_chart_filter_add),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/(?P<slug>\d+)$', image_chart_filter_detail,
         name='dashboard_app.views.image_reports.views.image_chart_filter_detail'),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/(?P<slug>\d+)/\+edit$', image_chart_filter_edit),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/(?P<slug>\d+)/\+delete$', image_chart_filter_delete),
     url(r'^api/link-bug-to-testrun', link_bug_to_testrun, name='lava_dashboard_link_bug_to_testrun'),
     url(r'^api/unlink-bug-and-testrun', unlink_bug_and_testrun, name='lava_dashboard_unlink_bug_and_testrun'),
