@@ -78,13 +78,17 @@ def append_failure_comment(job, msg):
     logger.error(msg)
 
 
-def create_metadata_store(results, job, level):
+def create_metadata_store(results, job):
     """
     Uses the OrderedDict import to correctly handle
     the yaml.load
     """
     if 'extra' not in results:
         return None
+    level = results.get('level')
+    if level is None:
+        return None
+
     logger = logging.getLogger('dispatcher-master')
     stub = "%s-%s-%s.yaml" % (results['definition'], results['case'], level)
     meta_filename = os.path.join(job.output_dir, 'metadata', stub)
@@ -439,10 +443,6 @@ def export_testcase(testcase):
     :param testcase: list of TestCase objects
     :return: Dictionary containing relevant information formatted for export
     """
-    actiondata = testcase.action_data
-    duration = float(actiondata.duration) if actiondata else ''
-    timeout = actiondata.timeout if actiondata else ''
-    level = actiondata.action_level if actiondata else None
     metadata = dict(testcase.action_metadata) if testcase.action_metadata else {}
     extra_source = []
     extra_data = metadata.get('extra', None)
@@ -460,12 +460,9 @@ def export_testcase(testcase):
         'result': str(testcase.result_code),
         'measurement': str(testcase.measurement),
         'unit': str(testcase.units),
-        'duration': str(duration),
-        'timeout': str(timeout),
-        'logged': str(testcase.logged),
-        'level': str(level),
-        'metadata': metadata,
         'url': str(testcase.get_absolute_url()),
-        'id': str(testcase.id)
+        'id': str(testcase.id),
+        'logged': str(testcase.logged),
+        'metadata': metadata,
     }
     return casedict
