@@ -381,7 +381,7 @@ class TestCase(models.Model, Queryable):
         if not self.metadata:
             return None
         try:
-            ret = yaml.load(self.metadata)
+            ret = yaml.load(self.metadata, Loader=yaml.CLoader)
         except yaml.YAMLError:
             return None
         return ret
@@ -1151,7 +1151,7 @@ class QueryCondition(models.Model):
         TestJob: [
             "submitter", "start_time", "end_time", "status", "actual_device",
             "requested_device_type", "health_check", "user", "group",
-            "priority", "is_pipeline"],
+            "priority", "is_pipeline", "description"],
         TestSuite: ["name"],
         TestCase: ["name", "result", "measurement"],
         NamedTestAttribute: []
