@@ -158,7 +158,11 @@ urlpatterns = [
         suite_csv_stream, name='lava.results.suite_csv_stream'),
     url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/yaml$',
         suite_yaml, name='lava.results.suite_yaml'),
-    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/(?P<case>[-_a-zA-Z0-9.\(\)+]+)$',
+    url(r'^testcase/(?P<case_id>[0-9]+)$',
+        testcase, name='lava.results.testcase'),
+    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/(?P<case_id>[0-9]+)$',
+        testcase, name='lava.results.testcase'),
+    url(r'^(?P<job>[0-9]+|[0-9]+.[0-9]+)/(?P<pk>[-_a-zA-Z0-9.]+)/(?P<case_id>[-_a-zA-Z0-9.\(\)+]+)$',
         testcase, name='lava.results.testcase'),
     url(r'^get-bug-links-json$', get_bug_links_json,
         name='lava.results.get_bug_links_json'),
