@@ -93,9 +93,12 @@ class TestSchedulerAPI(TestCaseWithFactory):  # pylint: disable=too-many-ancesto
         user.save()
         server = self.server_proxy('test', 'test')
         definition = self.factory.make_job_json()
-        job_id = server.scheduler.submit_job(definition)
-        job = TestJob.objects.get(id=job_id)
-        self.assertEqual(definition, job.definition)
+        try:
+            job_id = server.scheduler.submit_job(definition)
+        except xmlrpclib.Fault as f:
+            self.assertEqual(400, f.faultCode)
+        else:
+            self.fail("v1 job was accepted")
 
     def test_cancel_job_rejects_anonymous(self):
         job = self.factory.make_testjob()
@@ -205,9 +208,9 @@ actions:
     - test:
         name: kvm-basic-singlenode
         definitions:
-            - repository: git://git.linaro.org/qa/test-definitions.git
+            - repository: git://git.linaro.org/lava-team/lava-functional-tests.git
               from: git
-              path: ubuntu/smoke-tests-basic.yaml
+              path: lava-test-shell/smoke-tests-basic.yaml
               # name: if not present, use the name from the YAML. The name can
               # also be overriden from the actual commands being run by
               # calling the lava-test-suite-name API call (e.g.
