@@ -36,6 +36,7 @@ from lava_dispatcher.pipeline.test.test_defs import check_missing_path
 from lava_dispatcher.pipeline.action import JobError, InfrastructureError
 from lava_dispatcher.pipeline.actions.boot.qemu import BootQEMU
 from lava_dispatcher.pipeline.protocols.multinode import MultinodeProtocol
+from lava_dispatcher.pipeline.test.utils import DummyLogger
 from django_restricted_resource.managers import RestrictedResourceQuerySet
 from unittest import TestCase
 
@@ -580,7 +581,7 @@ class TestPipelineSubmit(TestCaseWithFactory):
             self.fail('[%d] device-dictionary error: %s' % (job.id, msg))
 
         self.assertTrue(device.is_valid(system=False))
-        device_object = PipelineDevice(device_config, device.hostname)  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
+        device_object = PipelineDevice(device_config)  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
         # FIXME: drop this nasty hack once 'target' is dropped as a parameter
         if 'target' not in device_object:
             device_object.target = device.hostname
@@ -836,7 +837,7 @@ class TestYamlMultinode(TestCaseWithFactory):
             self.fail('[%d] device-dictionary error: %s' % (host_job.id, msg))
 
         self.assertTrue(device.is_valid(system=False))
-        device_object = PipelineDevice(device_config, device.hostname)  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
+        device_object = PipelineDevice(device_config)  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
         # FIXME: drop this nasty hack once 'target' is dropped as a parameter
         if 'target' not in device_object:
             device_object.target = device.hostname
@@ -847,7 +848,7 @@ class TestYamlMultinode(TestCaseWithFactory):
             # pass (unused) output_dir just for validation as there is no zmq socket either.
             pipeline_job = parser.parse(
                 host_job.definition, parser_device,
-                host_job.id, None, "", output_dir=host_job.output_dir)
+                host_job.id, DummyLogger(), "", output_dir=host_job.output_dir)
         except (AttributeError, JobError, NotImplementedError, KeyError, TypeError) as exc:
             self.fail('[%s] parser error: %s' % (host_job.sub_id, exc))
         pipeline_job._validate(False)
@@ -857,7 +858,7 @@ class TestYamlMultinode(TestCaseWithFactory):
             # pass (unused) output_dir just for validation as there is no zmq socket either.
             pipeline_job = parser.parse(
                 guest_job.definition, parser_device,
-                guest_job.id, None, "", output_dir=guest_job.output_dir)
+                guest_job.id, DummyLogger(), "", output_dir=guest_job.output_dir)
         except (AttributeError, JobError, NotImplementedError, KeyError, TypeError) as exc:
             self.fail('[%s] parser error: %s' % (guest_job.sub_id, exc))
         pipeline_job._validate(False)
@@ -1096,7 +1097,7 @@ class TestYamlMultinode(TestCaseWithFactory):
                     msg = "Administrative error. Device '%s' has no device dictionary." % device.hostname
                     self.fail('[%d] device-dictionary error: %s' % (job.id, msg))
 
-                device_object = PipelineDevice(device_config, device.hostname)  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
+                device_object = PipelineDevice(device_config)  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
                 # FIXME: drop this nasty hack once 'target' is dropped as a parameter
                 if 'target' not in device_object:
                     device_object.target = device.hostname
@@ -1239,7 +1240,7 @@ class TestYamlMultinode(TestCaseWithFactory):
         device = Device.objects.get(hostname='fakeqemu1')
         device_config = device.load_configuration(job_ctx)  # raw dict
         self.assertTrue(device.is_valid(system=False))
-        parser_device = PipelineDevice(device_config, device.hostname)
+        parser_device = PipelineDevice(device_config)
         parser = JobParser()
         pipeline_job = parser.parse(
             yaml.dump(client_submission), parser_device,
@@ -1268,12 +1269,12 @@ class TestYamlMultinode(TestCaseWithFactory):
             meta_dict,
             {
                 'omitted.1.inline.name': 'ssh-client',
-                'test.0.definition.repository': 'git://git.linaro.org/qa/test-definitions.git',
+                'test.0.definition.repository': 'git://git.linaro.org/lava-team/lava-functional-tests.git',
                 'test.0.definition.name': 'smoke-tests',
                 'boot.0.method': 'ssh',
                 'omitted.1.inline.path': 'inline/ssh-client.yaml',
                 'test.0.definition.from': 'git',
-                'test.0.definition.path': 'ubuntu/smoke-tests-basic.yaml'
+                'test.0.definition.path': 'lava-test-shell/smoke-tests-basic.yaml'
             }
         )
 
@@ -1317,7 +1318,7 @@ class TestYamlMultinode(TestCaseWithFactory):
                     msg = "Administrative error. Device '%s' has no device dictionary." % device.hostname
                     self.fail('[%d] device-dictionary error: %s' % (job.id, msg))
 
-                device_object = PipelineDevice(device_config, device.hostname)  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
+                device_object = PipelineDevice(device_config)  # equivalent of the NewDevice in lava-dispatcher, without .yaml file.
                 # FIXME: drop this nasty hack once 'target' is dropped as a parameter
                 if 'target' not in device_object:
                     device_object.target = device.hostname
