@@ -126,6 +126,14 @@ if AUTH_LDAP_SERVER_URI:
         AUTH_LDAP_USER_FLAGS_BY_GROUP = distro_settings.get_setting(
             "AUTH_LDAP_USER_FLAGS_BY_GROUP")
 
+    if distro_settings.get_setting("AUTH_LDAP_REQUIRE_GROUP"):
+        AUTH_LDAP_REQUIRE_GROUP = distro_settings.get_setting(
+            "AUTH_LDAP_REQUIRE_GROUP")
+
+    if distro_settings.get_setting("AUTH_LDAP_DENY_GROUP"):
+        AUTH_LDAP_DENY_GROUP = distro_settings.get_setting(
+            "AUTH_LDAP_DENY_GROUP")
+
     # read any LDAP login message to use from the settings.conf
     LOGIN_MESSAGE_LDAP = distro_settings.get_setting("LOGIN_MESSAGE_LDAP", "")
 elif AUTH_DEBIAN_SSO:
@@ -153,7 +161,7 @@ BRANDING_URL = distro_settings.get_setting("BRANDING_URL", 'http://www.linaro.or
 BRANDING_HEIGHT = distro_settings.get_setting("BRANDING_HEIGHT", 22)
 BRANDING_WIDTH = distro_settings.get_setting("BRANDING_WIDTH", 22)
 BRANDING_BUG_URL = distro_settings.get_setting("BRANDING_BUG_URL", "https://bugs.linaro.org/enter_bug.cgi?product=LAVA%20Framework")
-BRANDING_SOURCE_URL = distro_settings.get_setting("BRANDING_SOURCE_URL", "https://git.linaro.org/gitweb?s=lava%2Flava")
+BRANDING_SOURCE_URL = distro_settings.get_setting("BRANDING_SOURCE_URL", "https://git.linaro.org/lava")
 BRANDING_MESSAGE = distro_settings.get_setting("BRANDING_MESSAGE", '')
 
 HIDE_V1_DOCS = distro_settings.get_setting("HIDE_V1_DOCS", False)
@@ -226,6 +234,9 @@ LOGGING = {
 # set to false in /etc/lava-server/settings.conf to hide the Results menu
 PIPELINE = distro_settings.get_setting("PIPELINE", True)
 
+# Make this instance read only
+ARCHIVED = distro_settings.get_setting("ARCHIVED", False)
+
 # Scheduler options
 SCHEDULER_DAEMON_OPTIONS.update(distro_settings.get_setting('SCHEDULER_DAEMON_OPTIONS', {}))
 
