@@ -26,7 +26,7 @@ import pydoc
 import random
 import xmlrpclib
 
-from django.contrib.auth.models import User
+from django.contrib.auth.models import AnonymousUser, User
 from django.db import models
 from django.utils import timezone
 
@@ -212,6 +212,19 @@ class ExposedAPI(object):
         return username
 
 
+class ExposedV2API(ExposedAPI):
+    @property
+    def user(self):
+        user = super(ExposedV2API, self).user
+        return AnonymousUser() if user is None else user
+
+    def _authenticate(self):
+        if not self.user.is_active:
+            raise xmlrpclib.Fault(
+                401, "Authentication with user and token required for this "
+                "API.")
+
+
 class Mapper(object):
     """
     Simple namespace for mapping multiple subclasses of ExposedAPI using one
